@@ -1,3 +1,28 @@
+# Created in August 2021
+#
+# Author: Azaria Zornberg
+#
+# Copyright 2021 - 2021 Azaria Zornberg
+#
+# This file is part of ms_active_directory
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
 """ Utilities for interacting with security-related aspects of an AD configuration, such as the
 password and encryption types.
 """
@@ -5,7 +30,7 @@ import random
 
 from ms_active_directory import logging_utils
 
-from typing import List
+from typing import List, Union
 
 from ms_active_directory.environment.security.security_config_constants import (
     AD_PASSWORD_CHAR_RANGE,
@@ -45,7 +70,7 @@ def generate_random_ad_password(password_length: int = 120):
     return password
 
 
-def get_supported_encryption_types_value(encryption_types: List[ADEncryptionType]):
+def get_supported_encryption_types_value(encryption_types: List[Union[str, ADEncryptionType]]):
     """ Calculates the number that represents the list of encryption types by adding their values
     in the bit map.
     """
@@ -79,7 +104,7 @@ def get_supported_encryption_type_enums_from_value(encryption_types_value: int):
     return encryption_types
 
 
-def normalize_encryption_type_list(encryption_types: List[ADEncryptionType]):
+def normalize_encryption_type_list(encryption_types: List[Union[str, ADEncryptionType]]):
     """ Given a list of encryption types, which may be strings or enums, normalize them to enums. """
     normalized_list = []
     valid_strings = sorted(ENCRYPTION_TYPE_STR_TO_ENUM.keys())
